@@ -1,8 +1,16 @@
-from gi import require_version
-from . import color_grid, template_grid, option_grid
-from wpgtk.data import files, themer, config
-from gi.repository import Gtk, GdkPixbuf
+import logging
 import os
+
+from . import color_grid
+from . import template_grid
+from . import option_grid
+from . import keyword_grid
+from ..data import files
+from ..data import themer
+from ..data.config import WALL_DIR, WPG_DIR, __version__
+
+from gi import require_version
+from gi.repository import Gtk, GdkPixbuf
 require_version('Gtk', '3.0')
 
 PAD = 10
@@ -11,20 +19,18 @@ PAD = 10
 class mainWindow(Gtk.Window):
 
     def __init__(self, args):
-        Gtk.Window.__init__(self, title='wpgtk ' + config.__version__)
+        Gtk.Window.__init__(self, title='wpgtk ' + __version__)
 
-        image_name = os.path.join(config.WALL_DIR, '.current')
+        image_name = os.path.join(WPG_DIR, '.current')
         image_name = os.path.realpath(image_name)
         self.set_default_size(200, 200)
         self.args = args
 
         # these variables are just to get the image
         # and preview of current wallpaper
-        route_list = image_name.split('/', image_name.count('/'))
-        file_name = route_list[4]
-        print('INF::CURRENT WALL: ' + file_name)
-        sample_name = os.path.join(config.SAMPLE_DIR,
-                                   (file_name + '.sample.png'))
+        file_name = themer.get_current()
+        logging.info('current wallpaper: ' + file_name)
+        sample_name = files.get_sample_path(file_name)
 
         self.notebook = Gtk.Notebook()
         self.add(self.notebook)
@@ -38,15 +44,23 @@ class mainWindow(Gtk.Window):
         self.cpage = color_grid.ColorGrid(self)
         self.fpage = template_grid.TemplateGrid(self)
         self.optpage = option_grid.OptionsGrid(self)
+        self.keypage = keyword_grid.KeywordGrid(self)
 
         self.notebook.append_page(self.wpage, Gtk.Label('Wallpapers'))
         self.notebook.append_page(self.cpage, Gtk.Label('Colors'))
         self.notebook.append_page(self.fpage, Gtk.Label('Templates'))
+        self.notebook.append_page(self.keypage, Gtk.Label('Keywords'))
         self.notebook.append_page(self.optpage, Gtk.Label('Options'))
 
         option_list = Gtk.ListStore(str)
-        for elem in list(files.get_file_list()):
+        current_idx = None
+
+        for (i, elem) in enumerate(files.get_file_list()):
+            if elem == themer.get_current():
+                current_idx = i
+
             option_list.append([elem])
+
         self.option_combo = Gtk.ComboBox.new_with_model(option_list)
         self.renderer_text = Gtk.CellRendererText()
         self.option_combo.pack_start(self.renderer_text, True)
@@ -61,8 +75,6 @@ class mainWindow(Gtk.Window):
         self.colorscheme.set_entry_text_column(0)
 
         self.set_border_width(10)
-        # another container will be added so this will probably change
-        # self.add(self.wpage)
         self.preview = Gtk.Image()
         self.sample = Gtk.Image()
 
@@ -79,8 +91,8 @@ class mainWindow(Gtk.Window):
 
         self.add_button = Gtk.Button(label='Add')
         self.set_button = Gtk.Button(label='Set')
-        self.set_button.set_sensitive(False)
         self.rm_button = Gtk.Button(label='Remove')
+
         # adds to first cell in wpage
         self.wpage.attach(self.option_combo, 1, 1, 2, 1)
         self.wpage.attach(self.colorscheme, 1, 2, 2, 1)
@@ -97,14 +109,20 @@ class mainWindow(Gtk.Window):
         self.entry = Gtk.Entry()
         self.current_walls = Gtk.ComboBox()
 
+        if current_idx is not None:
+            self.option_combo.set_active(current_idx)
+            self.colorscheme.set_active(current_idx)
+            self.cpage.option_combo.set_active(current_idx)
+            self.set_button.set_sensitive(True)
+
     def on_add_clicked(self, widget):
-        filepath = ""
         filechooser = Gtk.FileChooserDialog(
                       'Select an Image', self,
                       Gtk.FileChooserAction.OPEN,
                       (Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
                        Gtk.STOCK_OPEN, Gtk.ResponseType.OK))
 
+        filechooser.set_select_multiple(True)
         filefilter = Gtk.FileFilter()
         filefilter.set_name("Images")
         filefilter.add_mime_type("image/png")
@@ -114,20 +132,18 @@ class mainWindow(Gtk.Window):
         response = filechooser.run()
 
         if response == Gtk.ResponseType.OK:
-            filepath = filechooser.get_filename()
+            for f in filechooser.get_filenames():
+                themer.create_theme(f)
+            option_list = Gtk.ListStore(str)
+            for elem in list(files.get_file_list()):
+                option_list.append([elem])
+            self.option_combo.set_model(option_list)
+            self.option_combo.set_entry_text_column(0)
+            self.colorscheme.set_model(option_list)
+            self.colorscheme.set_entry_text_column(0)
+            self.cpage.update_combo(option_list)
         filechooser.destroy()
 
-        themer.create_theme(filepath)
-        option_list = Gtk.ListStore(str)
-
-        for elem in list(files.get_file_list()):
-            option_list.append([elem])
-        self.option_combo.set_model(option_list)
-        self.option_combo.set_entry_text_column(0)
-        self.colorscheme.set_model(option_list)
-        self.colorscheme.set_entry_text_column(0)
-        self.cpage.update_combo(option_list)
-
     def on_set_clicked(self, widget):
         x = self.option_combo.get_active()
         y = self.colorscheme.get_active()
@@ -135,7 +151,7 @@ class mainWindow(Gtk.Window):
         if current_walls:
             filename = current_walls[x]
             colorscheme_file = current_walls[y]
-            themer.set_theme(filename, colorscheme_file, self.args.v)
+            themer.set_theme(filename, colorscheme_file)
 
     def on_rm_clicked(self, widget):
         x = self.option_combo.get_active()
@@ -157,7 +173,7 @@ class mainWindow(Gtk.Window):
         x = self.option_combo.get_active()
         self.colorscheme.set_active(x)
         selected_file = files.get_file_list()[x]
-        filepath = os.path.join(config.WALL_DIR, selected_file)
+        filepath = os.path.join(WALL_DIR, selected_file)
 
         self.pixbuf_preview = GdkPixbuf.Pixbuf.new_from_file_at_scale(
             str(filepath),
@@ -168,13 +184,8 @@ class mainWindow(Gtk.Window):
 
     def colorscheme_box_change(self, widget):
         x = self.colorscheme.get_active()
-        selected_file = files.get_file_list()[x]
-        samplepath = os.path.join(config.SAMPLE_DIR,
-                                  (selected_file + '.sample.png'))
-        if(os.path.isfile(samplepath)):
-            self.pixbuf_sample = GdkPixbuf.Pixbuf.new_from_file_at_size(
-                                 samplepath, width=500, height=500)
-        self.sample.set_from_pixbuf(self.pixbuf_sample)
+
+        # set the ComboBox in color_grid
         self.cpage.set_edit_combo(x)
 
 
